@@ -1,7 +1,7 @@
 """git support
 """
 
-# pylint: disable= invalid-name, bad-whitespace
+# pylint: disable= invalid-name
 
 # test like this:
 # cd test/src
@@ -16,7 +16,7 @@ import re
 import sumolib.system
 import sumolib.utils
 
-__version__="4.1.2" #VERSION#
+__version__="4.1.3" #VERSION#
 
 assert __version__==sumolib.system.__version__
 assert __version__==sumolib.utils.__version__
@@ -306,8 +306,6 @@ class Repo():
         opts= "-c advice.detachedHead=false -q"
         if tag:
             opts+= " -b %s" % tag
-        if rev:
-            opts+= " -b %s" % rev
         cmd= "git clone %s %s %s" % (opts, url, destdir)
         sumolib.system.system(cmd, False, False, None, verbose, dry_run)
         # the following to avoid warning if we use "git push" in this
@@ -319,6 +317,23 @@ class Repo():
                                   verbose, dry_run)
         finally:
             sumolib.system.changedir(cwd, verbose, dry_run)
+        if (tag is None) and (rev is None):
+            # nothing more to do, HEAD was checked out
+            return
+        if tag is not None:
+            # tag/branch was given. Due to option "-b" with "git clone"
+            # everything is already set up correctly, we have nothing more to
+            # do.
+            return
+        # From here: (rev is not None)
+        # We have to run checkout:
+        opts= "-q"
+        cmd="git checkout %s %s" % (opts, rev)
+        cwd= sumolib.system.changedir(destdir, verbose, dry_run)
+        try:
+            sumolib.system.system(cmd, False, False, None, verbose, dry_run)
+        finally:
+            sumolib.system.changedir(cwd, verbose, dry_run)
     def commit(self, logmessage):
         """commit changes."""
         if not logmessage:
